==> haskell-hspec-wai-0.11.1-415-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-wai.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hspec-wai
version:              0.11.1
visibility:           public
id:                   hspec-wai-0.11.1-JSDm24FS6O98dcv2gdEmhw
key:                  hspec-wai-0.11.1-JSDm24FS6O98dcv2gdEmhw
license:              MIT
copyright:
    (c) 2012-2014 Fujimura Daisuke,
    (c) 2014-2018 Simon Hengel

maintainer:
    Fujimura Daisuke <me@fujimuradaisuke.com>,
    Simon Hengel <sol@typeful.net>

author:
    Fujimura Daisuke <me@fujimuradaisuke.com>,
    Simon Hengel <sol@typeful.net>

homepage:             https://github.com/hspec/hspec-wai#readme
synopsis:             Experimental Hspec support for testing WAI applications
description:          Experimental Hspec support for testing WAI applications
category:             Testing
abi:                  a4ca49ab6e5f3e2370fc5e8be7b66639
exposed:              True
exposed-modules:
    Test.Hspec.Wai Test.Hspec.Wai.Internal Test.Hspec.Wai.Matcher
    Test.Hspec.Wai.QuickCheck

hidden-modules:       Test.Hspec.Wai.Util Paths_hspec_wai
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hspec-wai-0.11.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hspec-wai-0.11.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-wai
hs-libraries:         HShspec-wai-0.11.1-JSDm24FS6O98dcv2gdEmhw
depends:
    QuickCheck-2.14.3-7KAyoz665FX6hCYaBEoJHk base-4.16.4.0
    base-compat-0.12.2-5hQPtIjgG5LKnb20qwjRWd bytestring-0.11.4.0
    case-insensitive-1.2.1.0-2Tjf2PFkxP43DkqVUMYCmf
    hspec-core-2.10.9-AxO0DnVN1S59OHkE19ibUD
    hspec-expectations-0.8.3-1zJ9Bt2UKIO1izJ8suxZW5
    http-types-0.12.4-B3znMwHTe3dL304Bd3IJgZ text-1.2.5.0
    transformers-0.5.6.2 wai-3.2.4-JJVI15W7E9rGAtOPSLOeBU
    wai-extra-3.1.14-KCWuHky1wkt7UnW34KzUw6

haddock-interfaces:   /usr/share/doc/haskell-hspec-wai/html/hspec-wai.haddock
haddock-html:         /usr/share/doc/haskell-hspec-wai/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-wai-0.11.1-417-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-wai.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hspec-wai
version:              0.11.1
visibility:           public
id:                   hspec-wai-0.11.1-eGRlvD0iKLA80HeDcMVKh
key:                  hspec-wai-0.11.1-eGRlvD0iKLA80HeDcMVKh
license:              MIT
copyright:
    (c) 2012-2014 Fujimura Daisuke,
    (c) 2014-2018 Simon Hengel

maintainer:
    Fujimura Daisuke <me@fujimuradaisuke.com>,
    Simon Hengel <sol@typeful.net>

author:
    Fujimura Daisuke <me@fujimuradaisuke.com>,
    Simon Hengel <sol@typeful.net>

homepage:             https://github.com/hspec/hspec-wai#readme
synopsis:             Experimental Hspec support for testing WAI applications
description:          Experimental Hspec support for testing WAI applications
category:             Testing
abi:                  9d522a77be6ee2eedab6aaffa32dc82a
exposed:              True
exposed-modules:
    Test.Hspec.Wai Test.Hspec.Wai.Internal Test.Hspec.Wai.Matcher
    Test.Hspec.Wai.QuickCheck

hidden-modules:       Test.Hspec.Wai.Util Paths_hspec_wai
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hspec-wai-0.11.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hspec-wai-0.11.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-wai
hs-libraries:         HShspec-wai-0.11.1-eGRlvD0iKLA80HeDcMVKh
depends:
    QuickCheck-2.14.3-JVpLupMbhPgL6XTp3rPxED base-4.16.4.0
    base-compat-0.12.2-5hQPtIjgG5LKnb20qwjRWd bytestring-0.11.4.0
    case-insensitive-1.2.1.0-BBCkGXkqh3nGRz3m4HFNUT
    hspec-core-2.10.9-6Oo46zOT12G3ZYTFJbCUOO
    hspec-expectations-0.8.3-1zJ9Bt2UKIO1izJ8suxZW5
    http-types-0.12.4-IbDJVwQVDeTAnHs7wyLMrJ text-1.2.5.0
    transformers-0.5.6.2 wai-3.2.4-BbAdcKGl4jbBaSv8iBtxy6
    wai-extra-3.1.14-9WB77WsnpAo5i5EJiSrnVy

haddock-interfaces:   /usr/share/doc/haskell-hspec-wai/html/hspec-wai.haddock
haddock-html:         /usr/share/doc/haskell-hspec-wai/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
